@@ -7,7 +7,7 @@ from .settings import settings
 
 region = settings.AWS_REGION
 
-if settings.ENVIRONMENT == 'local':  # not gonna need this on local
+if settings.ENVIRONMENT != 'local':  # not gonna need this on local
     dynamodb = boto3.resource('dynamodb', region_name=region)
     s3 = boto3.resource('s3', region_name=region)
 
