@@ -35,6 +35,8 @@ class ServiceUrl:
     tms = Record('tms-service', 'srv')
     location = Record('location-service', 'srv')
     pricing = Record('pricing-service', 'srv')
+    ai = Record('litto-service', 'srv')
+    bidding = Record('bidding-service', 'srv')
 
 
 service_url = ServiceUrl(settings.ENVIRONMENT)
